import { useState, useMemo, useCallback } from 'react';
import { Helmet } from 'react-helmet-async';
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Checkbox } from '@/components/ui/checkbox';
import { Badge } from '@/components/ui/badge';
import { Dialog, DialogContent, DialogDescription, DialogHeader, DialogTitle, DialogTrigger } from '@/components/ui/dialog';
import { Calculator as CalculatorIcon, Euro, ArrowRight, ArrowLeft, Building2, Heart, ShoppingCart, Users, Factory, GraduationCap, Briefcase, TrendingUp, MoreHorizontal, HelpCircle, Check, Sparkles, Zap } from 'lucide-react';
import { SubpageScrollReset } from '@/components/SubpageScrollReset';
import { Footer } from '@/components/Footer';
import { Link } from 'react-router-dom';
import { useIsMobile } from '@/hooks/use-mobile';
import { useAnalytics } from '@/hooks/useAnalytics';

// Industry types with base pricing and icons
const industries = [
  { id: 'restaurant', name: 'Restaurant & Gastronomie', basePrice: 10, multiplier: 1.0, icon: Users, description: 'Restaurants, Cafés, Catering' },
  { id: 'healthcare', name: 'Gesundheitswesen', basePrice: 10, multiplier: 1.0, icon: Heart, description: 'Arztpraxen, Kliniken, Therapie' },
  { id: 'retail', name: 'Einzelhandel & E-Commerce', basePrice: 10, multiplier: 1.0, icon: ShoppingCart, description: 'Online-Shops, Einzelhandel' },
  { id: 'services', name: 'Dienstleistungen', basePrice: 10, multiplier: 1.0, icon: Briefcase, description: 'Beratung, Services, Freelancer' },
  { id: 'manufacturing', name: 'Produktion & Fertigung', basePrice: 10, multiplier: 1.0, icon: Factory, description: 'Industrie, Handwerk, Produktion' },
  { id: 'nonprofit', name: 'Non-Profit & Vereine', basePrice: 10, multiplier: 1.0, icon: Heart, description: 'Vereine, Stiftungen, NGOs' },
  { id: 'education', name: 'Bildung & Training', basePrice: 10, multiplier: 1.0, icon: GraduationCap, description: 'Schulen, Kurse, Weiterbildung' },
  { id: 'real-estate', name: 'Immobilien', basePrice: 10, multiplier: 1.0, icon: Building2, description: 'Makler, Verwaltung, Bau' },
  { id: 'finance', name: 'Finanzen & Beratung', basePrice: 10, multiplier: 1.0, icon: TrendingUp, description: 'Banken, Versicherungen, Beratung' },
  { id: 'other', name: 'Sonstiges', basePrice: 10, multiplier: 1.0, icon: MoreHorizontal, description: 'Andere Branchen' }
];

// Adjusted features with pricing that adds up to exactly 60€ (so with base price 10€ = 70€ total)
const features = [
  { 
    id: 'contact-form', 
    name: 'Kontaktformular', 
    price: 5,
    description: 'Ein professionelles Kontaktformular mit dem Besucher direkt mit Ihnen in Kontakt treten können. Inklusive Spam-Schutz und automatische E-Mail-Weiterleitung.'
  },
  { 
    id: 'gallery', 
    name: 'Bildergalerie', 
    price: 5,
    description: 'Eine responsive Bildergalerie zur ansprechenden Präsentation Ihrer Produkte, Dienstleistungen oder Projekte. Mit Lightbox-Funktion und automatischer Bildoptimierung.'
  },
  { 
    id: 'price-list', 
    name: 'Preisliste', 
    price: 6,
    description: 'Eine übersichtliche Darstellung Ihrer Preise und Leistungen. Ideal für Dienstleister, Restaurants oder Shops um Transparenz zu schaffen.'
  },
  { 
    id: 'about-us', 
    name: 'Über Uns', 
    price: 4,
    description: 'Eine professionelle "Über Uns" Seite die Ihr Unternehmen, Ihr Team und Ihre Geschichte vorstellt. Baut Vertrauen und Glaubwürdigkeit auf.'
  },
  { 
    id: 'reviews', 
    name: 'Bewertungen', 
    price: 5,
    description: 'Ein Bewertungssystem zur Anzeige von Kundenbewertungen und Testimonials. Stärkt das Vertrauen neuer Kunden in Ihre Dienstleistungen.'
  },
  { 
    id: 'blog', 
    name: 'Blog/News', 
    price: 12,
    description: 'Ein Blog-Bereich für regelmäßige Inhalte, News und Updates. Verbessert SEO und hält Ihre Website aktuell und interessant für Besucher.'
  },
  { 
    id: 'portfolio', 
    name: 'Portfolio', 
    price: 7,
    description: 'Eine Showcase-Seite für Ihre Arbeiten, Projekte oder Referenzen. Ideal für Kreative, Agenturen oder Dienstleister um Ihr Können zu präsentieren.'
  },
  { 
    id: 'seo', 
    name: 'SEO - Optimierung', 
    price: 8,
    description: 'Erweiterte Suchmaschinenoptimierung für bessere Sichtbarkeit bei Google. Inklusive Meta-Tags, strukturierte Daten und Performance-Optimierung.'
  },
  { 
    id: 'social-media', 
    name: 'Social Media Links', 
    price: 3,
    description: 'Integration Ihrer Social Media Profile (Facebook, Instagram, LinkedIn etc.) mit ansprechenden Icons und direkten Verlinkungen.'
  },
  { 
    id: 'google-maps', 
    name: 'Google Maps Integration', 
    price: 3,
    description: 'Einbettung einer interaktiven Google Maps Karte mit Ihrem Standort. Erleichtert Kunden das Finden Ihres Geschäfts oder Büros.'
  },
  { 
    id: 'whatsapp', 
    name: 'WhatsApp', 
    price: 2,
    description: 'WhatsApp-Button für direkten Kontakt über die beliebte Messaging-App. Ermöglicht schnelle und unkomplizierte Kommunikation mit Kunden.'
  },
  { 
    id: 'analytics', 
    name: 'Analytics & Tracking', 
    price: 5,
    description: 'Einrichtung von Google Analytics und anderen Tracking-Tools um Besucherverhalten zu verstehen und die Website kontinuierlich zu verbessern.'
  }
];

export default function Calculator() {
  const [currentStep, setCurrentStep] = useState(1);
  const [selectedIndustry, setSelectedIndustry] = useState<string>('');
  const [selectedFeatures, setSelectedFeatures] = useState<string[]>([]);
  const [showResult, setShowResult] = useState(false);
  const [helpDialogOpen, setHelpDialogOpen] = useState(false);
  const isMobile = useIsMobile();
  const analytics = useAnalytics();

  const handleIndustrySelect = (industryId: string) => {
    const industry = industries.find(i => i.id === industryId);
    setSelectedIndustry(industryId);
    setCurrentStep(2);
    
    // Track industry selection
    analytics.trackEvent('Calculator', 'Industry Selected', industry?.name || industryId);
  };

  const handleFeatureToggle = useCallback((featureId: string, checked: boolean) => {
    const feature = features.find(f => f.id === featureId);
    
    if (checked) {
      setSelectedFeatures(prev => [...prev, featureId]);
      analytics.trackEvent('Calculator', 'Feature Added', feature?.name || featureId);
    } else {
      setSelectedFeatures(prev => prev.filter(id => id !== featureId));
      analytics.trackEvent('Calculator', 'Feature Removed', feature?.name || featureId);
    }
  }, [analytics]);

  const handleCardClick = (featureId: string, event: React.MouseEvent) => {
    // Prevent default behavior to avoid text selection
    event.preventDefault();
    
    // Prevent the event if it's coming from the checkbox itself
    if ((event.target as HTMLElement).closest('[role="checkbox"]')) {
      return;
    }
    
    const isCurrentlySelected = selectedFeatures.includes(featureId);
    handleFeatureToggle(featureId, !isCurrentlySelected);
  };

  const calculatePricing = useMemo(() => {
    if (!selectedIndustry) return { totalPrice: 0, webFlatMonthly: 0, smartStartInitial: 0, smartStartMonthly: 0 };

    const industry = industries.find(i => i.id === selectedIndustry);
    if (!industry) return { totalPrice: 0, webFlatMonthly: 0, smartStartInitial: 0, smartStartMonthly: 0 };

    const basePrice = industry.basePrice;
    
    const featuresPrice = selectedFeatures.reduce((total, featureId) => {
      const feature = features.find(f => f.id === featureId);
      return total + (feature?.price || 0);
    }, 0);

    const monthlyPrice = Math.round((basePrice + featuresPrice) * industry.multiplier);
    
    // WebFlat: Monthly price
    const webFlatMonthly = monthlyPrice;
    
    // SmartStart: Monthly price * 10 for initial, then 40% monthly
    const smartStartInitial = monthlyPrice * 10;
    const smartStartMonthly = Math.round(monthlyPrice * 0.4);

    return { totalPrice: monthlyPrice, webFlatMonthly, smartStartInitial, smartStartMonthly };
  }, [selectedIndustry, selectedFeatures]);

  const handleCalculate = () => {
    const pricing = calculatePricing;
    const selectedIndustryData = industries.find(i => i.id === selectedIndustry);
    
    setShowResult(true);
    
    // Track calculation completion
    analytics.trackEvent('Calculator', 'Calculation Completed', `Industry: ${selectedIndustryData?.name}, Features: ${selectedFeatures.length}, Price: €${pricing.webFlatMonthly}`);
    analytics.trackEvent('Calculator', 'Pricing Calculated', 'WebFlat', pricing.webFlatMonthly);
    analytics.trackEvent('Calculator', 'Pricing Calculated', 'SmartStart Initial', pricing.smartStartInitial);
  };

  const handleBackToIndustry = () => {
    setCurrentStep(1);
    setSelectedIndustry('');
    setSelectedFeatures([]);
    setShowResult(false);
    
    // Track navigation
    analytics.trackButtonClick('Back to Industry Selection', 'Calculator Navigation');
  };

  const handleBackToFeatures = () => {
    setShowResult(false);
    
    // Track navigation
    analytics.trackButtonClick('Back to Features', 'Calculator Navigation');
  };

  const handleHelpDialogOpen = (open: boolean) => {
    setHelpDialogOpen(open);
    
    if (open) {
      analytics.trackEvent('Calculator', 'Help Dialog Opened', 'Features Help');
    }
  };

  const handlePackageInterest = (packageType: 'WebFlat' | 'SmartStart') => {
    const pricing = calculatePricing;
    const selectedIndustryData = industries.find(i => i.id === selectedIndustry);
    
    analytics.trackEvent('Calculator', 'Package Interest', packageType);
    analytics.trackEvent('Calculator', 'Contact Intent', `${packageType} - Industry: ${selectedIndustryData?.name}`);
    analytics.trackButtonClick(`${packageType} More Info`, 'Calculator Results');
  };

  const pricing = calculatePricing;
  const selectedIndustryData = industries.find(i => i.id === selectedIndustry);

  return (
    <>
      <div className="min-h-screen bg-gradient-to-br from-slate-900 via-blue-900/50 to-slate-900 relative overflow-hidden">
        {/* Animated background elements - more refined */}
        <div className="absolute inset-0 overflow-hidden">
          <div className="absolute -top-40 -right-40 w-80 h-80 bg-blue-500/10 rounded-full blur-3xl animate-pulse-slow"></div>
          <div className="absolute top-1/3 -left-20 w-60 h-60 bg-indigo-500/10 rounded-full blur-3xl animate-float"></div>
          <div className="absolute bottom-20 right-1/4 w-40 h-40 bg-purple-500/10 rounded-full blur-3xl animate-pulse-slow"></div>
        </div>

        <Helmet>
          <title>Website Kalkulator - Walbostudios</title>
          <meta name="description" content="Berechnen Sie die Kosten für Ihre neue Website. Wählen Sie Ihre Branche und gewünschte Funktionen für eine schnelle Kostenschätzung." />
        </Helmet>
        <SubpageScrollReset />
        
        <div className="container py-12 relative z-10">
          <div className="max-w-6xl mx-auto">
            {/* Back to Home Link */}
            <div className="mb-8">
              <Button asChild variant="ghost" className="group text-white hover:text-gray-300 hover:bg-white/10 backdrop-blur-sm border border-white/10">
                <Link 
                  to="/" 
                  className="flex items-center gap-2"
                  onClick={() => analytics.trackButtonClick('Back to Home', 'Calculator Navigation')}
                >
                  <ArrowLeft className="h-4 w-4 transition-transform group-hover:-translate-x-1" />
                  Zurück zur Hauptseite
                </Link>
              </Button>
            </div>

            {/* Header */}
            <div className="text-center mb-16">
              <div className="inline-flex items-center justify-center mb-8 bg-gradient-to-r from-blue-500/20 to-indigo-500/20 p-6 rounded-full backdrop-blur-sm border border-white/10 animate-float">
                <CalculatorIcon className="h-10 w-10 text-blue-400" />
                <Sparkles className="h-6 w-6 text-indigo-300 ml-2 animate-pulse" />
              </div>
              <h1 className="text-5xl md:text-7xl font-bold mb-8 bg-gradient-to-r from-blue-300 via-indigo-300 to-blue-400 bg-clip-text text-transparent leading-tight">
                Website Kalkulator
              </h1>
              <p className="text-xl md:text-2xl text-gray-300 max-w-3xl mx-auto leading-relaxed">
                Erhalten Sie eine <span className="text-blue-400 font-semibold">schnelle</span> und <span className="text-indigo-400 font-semibold">transparente</span> Kostenschätzung für Ihr Webprojekt. 
                Wählen Sie Ihre Branche und gewünschte Funktionen aus.
              </p>
            </div>

            {/* Enhanced Step Indicator - Mobile Responsive */}
            <div className="flex items-center justify-center mb-12">
              <div className={`flex items-center bg-white/5 backdrop-blur-sm p-4 rounded-full border border-white/10 ${isMobile ? 'space-x-3' : 'space-x-6'}`}>
                <div className={`flex items-center justify-center rounded-full transition-all duration-300 ${isMobile ? 'w-8 h-8' : 'w-12 h-12'} ${currentStep >= 1 ? 'bg-gradient-to-r from-blue-500 to-indigo-500 text-white shadow-lg shadow-blue-500/30' : 'bg-gray-600 text-gray-400'}`}>
                  <span className={`font-bold ${isMobile ? 'text-sm' : ''}`}>1</span>
                </div>
                <div className={`rounded-full transition-all duration-300 ${isMobile ? 'h-1 w-12' : 'h-2 w-20'} ${currentStep >= 2 ? 'bg-gradient-to-r from-blue-500 to-indigo-500' : 'bg-gray-600'}`}></div>
                <div className={`flex items-center justify-center rounded-full transition-all duration-300 ${isMobile ? 'w-8 h-8' : 'w-12 h-12'} ${currentStep >= 2 ? 'bg-gradient-to-r from-blue-500 to-indigo-500 text-white shadow-lg shadow-blue-500/30' : 'bg-gray-600 text-gray-400'}`}>
                  <span className={`font-bold ${isMobile ? 'text-sm' : ''}`}>2</span>
                </div>
                <div className={`rounded-full transition-all duration-300 ${isMobile ? 'h-1 w-12' : 'h-2 w-20'} ${showResult ? 'bg-gradient-to-r from-blue-500 to-indigo-500' : 'bg-gray-600'}`}></div>
                <div className={`flex items-center justify-center rounded-full transition-all duration-300 ${isMobile ? 'w-8 h-8' : 'w-12 h-12'} ${showResult ? 'bg-gradient-to-r from-blue-500 to-indigo-500 text-white shadow-lg shadow-blue-500/30' : 'bg-gray-600 text-gray-400'}`}>
                  <span className={`font-bold ${isMobile ? 'text-sm' : ''}`}>3</span>
                </div>
              </div>
            </div>

            {/* Step 1: Industry Selection */}
            {currentStep === 1 && (
              <div className="space-y-8">
                <div className="text-center mb-12">
                  <h2 className="text-3xl font-bold mb-4 text-white">Schritt 1: Wählen Sie Ihre Branche</h2>
                  <p className="text-gray-300 text-lg">Klicken Sie auf die Karte, die am besten zu Ihrem Unternehmen passt.</p>
                </div>
                <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
                  {industries.map((industry, index) => {
                    const IconComponent = industry.icon;
                    return (
                      <Card 
                        key={industry.id}
                        className="cursor-pointer transition-all duration-500 hover:shadow-2xl hover:shadow-blue-500/20 hover:scale-105 hover:border-blue-400/50 bg-white/5 backdrop-blur-sm border-white/10 group animate-fade-in"
                        style={{ animationDelay: `${index * 100}ms` }}
                        onClick={() => handleIndustrySelect(industry.id)}
                      >
                        <CardHeader className="text-center relative">
                          <div className="inline-flex items-center justify-center mb-6 bg-gradient-to-r from-blue-500/20 to-indigo-500/20 p-4 rounded-full mx-auto group-hover:scale-110 transition-transform duration-300 border border-white/10">
                            <IconComponent className="h-8 w-8 text-blue-400 group-hover:text-blue-300 transition-colors" />
                          </div>
                          <CardTitle className="text-xl text-white group-hover:text-blue-300 transition-colors">{industry.name}</CardTitle>
                          <CardDescription className="text-gray-400 group-hover:text-gray-300 transition-colors">{industry.description}</CardDescription>
                        </CardHeader>
                      </Card>
                    );
                  })}
                </div>
              </div>
            )}

            {/* Step 2: Feature Selection */}
            {currentStep === 2 && !showResult && (
              <div className="space-y-8">
                <div className={`${isMobile ? 'space-y-4' : 'flex items-center justify-between'} mb-12`}>
                  <div>
                    <h2 className="text-3xl font-bold mb-4 text-white">Schritt 2: Wählen Sie Ihre Funktionen</h2>
                    <p className="text-gray-300 text-lg">
                      Gewählte Branche: <span className="text-blue-400 font-semibold">{selectedIndustryData?.name}</span>
                    </p>
                    {isMobile && (
                      <div className="mt-4">
                        <Button variant="outline" onClick={handleBackToIndustry} className="bg-blue-500/20 border-blue-400/50 text-blue-300 hover:bg-blue-500/30 hover:border-blue-300 backdrop-blur-sm transition-all duration-300">
                          <ArrowLeft className="h-4 w-4 mr-2" />
                          Branche ändern
                        </Button>
                      </div>
                    )}
                  </div>
                  {!isMobile && (
                    <Button variant="outline" onClick={handleBackToIndustry} className="bg-blue-500/20 border-blue-400/50 text-blue-300 hover:bg-blue-500/30 hover:border-blue-300 backdrop-blur-sm transition-all duration-300">
                      <ArrowLeft className="h-4 w-4 mr-2" />
                      Branche ändern
                    </Button>
                  )}
                </div>

                <Card className="bg-white/5 backdrop-blur-sm border-white/10 shadow-2xl">
                  <CardHeader>
                    <CardTitle className="flex items-center justify-between text-white">
                      <span className="flex items-center gap-3 text-2xl">
                        <Zap className="h-6 w-6 text-indigo-400" />
                        Gewünschte Funktionen
                        <Dialog open={helpDialogOpen} onOpenChange={handleHelpDialogOpen}>
                          <DialogTrigger asChild>
                            <Button variant="outline" size="sm" className="ml-4 bg-indigo-500/20 border-indigo-400/50 text-indigo-300 hover:bg-indigo-500/30 hover:border-indigo-300 backdrop-blur-sm transition-all duration-300">
                              <HelpCircle className="h-4 w-4 mr-1" />
                              Hilfe
                            </Button>
                          </DialogTrigger>
                          <DialogContent className="max-w-2xl max-h-[80vh] overflow-y-auto bg-gray-900/95 backdrop-blur-md border-white/20">
                            <DialogHeader>
                              <DialogTitle className="text-white text-xl">Funktionen erklärt</DialogTitle>
                              <DialogDescription className="text-gray-300">
                                Hier finden Sie eine Erklärung aller verfügbaren Funktionen für Ihre Website.
                              </DialogDescription>
                            </DialogHeader>
                            <div className="space-y-6">
                              {features.map((feature) => (
                                <div key={feature.id} className="border-b border-white/10 pb-4 last:border-b-0">
                                  <h4 className="font-medium text-lg mb-2 text-white">{feature.name}</h4>
                                  <p className="text-sm text-gray-400 leading-relaxed">{feature.description}</p>
                                </div>
                              ))}
                            </div>
                          </DialogContent>
                        </Dialog>
                      </span>
                    </CardTitle>
                    <CardDescription className="text-gray-400 text-lg">
                      Wählen Sie die Funktionen aus, die Ihre Website benötigt.
                    </CardDescription>
                  </CardHeader>
                  <CardContent>
                    <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-6">
                      {features.map((feature, index) => (
                        <div
                          key={feature.id}
                          className={`flex items-center space-x-4 p-6 rounded-xl border transition-all duration-300 cursor-pointer select-none group animate-fade-in ${
                            selectedFeatures.includes(feature.id)
                              ? 'bg-gradient-to-r from-blue-500/20 to-indigo-500/20 border-blue-400/50 shadow-lg shadow-blue-500/20'
                              : 'bg-white/5 border-white/10 hover:bg-white/10 hover:border-white/20'
                          }`}
                          style={{ animationDelay: `${index * 50}ms` }}
                          onClick={(event) => handleCardClick(feature.id, event)}
                          onMouseDown={(e) => e.preventDefault()}
                        >
                          <Checkbox
                            id={feature.id}
                            checked={selectedFeatures.includes(feature.id)}
                            onCheckedChange={(checked) => handleFeatureToggle(feature.id, checked as boolean)}
                            className="border-white/30 data-[state=checked]:bg-blue-500 data-[state=checked]:border-blue-500"
                          />
                          <div className="flex-1">
                            <label
                              htmlFor={feature.id}
                              className="text-base font-medium leading-none cursor-pointer text-white select-none group-hover:text-blue-300 transition-colors"
                              onMouseDown={(e) => e.preventDefault()}
                            >
                              {feature.name}
                            </label>
                          </div>
                        </div>
                      ))}
                    </div>
                  </CardContent>
                </Card>

                <div className="text-center">
                  <Button size="lg" onClick={handleCalculate} className="px-12 py-4 text-lg bg-gradient-to-r from-blue-600 to-indigo-600 hover:from-blue-700 hover:to-indigo-700 shadow-lg shadow-blue-500/30 border-0">
                    <Euro className="mr-3 h-6 w-6" />
                    Kosten berechnen
                    <ArrowRight className="ml-3 h-6 w-6" />
                  </Button>
                </div>
              </div>
            )}

            {/* Step 3: Pricing Options */}
            {showResult && (
              <div className="space-y-8">
                <div className="text-center mb-12">
                  <h2 className="text-4xl font-bold mb-6 bg-gradient-to-r from-blue-300 via-indigo-300 to-blue-400 bg-clip-text text-transparent">
                    Deine Kostenschätzung
                  </h2>
                  <p className="text-gray-300 text-lg mb-2">
                    Basierend auf Deiner Auswahl haben wir zwei mögliche Pakete kalkuliert. Dies ist
                  </p>
                  <p className="text-gray-300 text-lg mb-2">
                    eine unverbindliche Schätzung, der endgültige Preis wird nach einem persönlichen
                  </p>
                  <p className="text-gray-300 text-lg">
                    Gespräch festgelegt.
                  </p>
                  <div className="flex items-center justify-center mt-6">
                    <Button variant="outline" onClick={handleBackToFeatures} className="bg-blue-500/20 border-blue-400/50 text-blue-300 hover:bg-blue-500/30 hover:border-blue-300 backdrop-blur-sm transition-all duration-300">
                      <ArrowLeft className="h-4 w-4 mr-2" />
                      Funktionen ändern
                    </Button>
                  </div>
                </div>

                <div className="grid lg:grid-cols-2 gap-10 max-w-5xl mx-auto">
                  {/* WebFlat Package */}
                  <Card className="bg-gradient-to-br from-blue-900/30 to-indigo-800/30 backdrop-blur-sm border-blue-400/30 relative overflow-hidden group hover:shadow-2xl hover:shadow-blue-500/20 transition-all duration-500">
                    <div className="absolute inset-0 bg-gradient-to-br from-blue-500/5 to-transparent opacity-0 group-hover:opacity-100 transition-opacity duration-500"></div>
                    <CardHeader className="text-center pb-6 relative z-10">
                      <div className="text-blue-400 text-3xl font-bold mb-3">WebFlat</div>
                      <div className="text-gray-300 text-base mb-6">
                        Ideal für den Start & kontinuierliche Betreuung
                      </div>
                      <div className="flex items-baseline justify-center mb-2">
                        <span className="text-5xl font-bold text-white">{pricing.webFlatMonthly}</span>
                        <span className="text-2xl font-bold text-white">,00 €</span>
                        <span className="text-gray-400 ml-3 text-lg">/ Monat</span>
                      </div>
                      <div className="text-sm text-gray-400 mt-2">Mindestlaufzeit: 12 Monate</div>
                    </CardHeader>
                    <CardContent className="space-y-6 relative z-10">
                      <div className="space-y-4">
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Geringe Startkosten</span>
                        </div>
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Laufende Wartung & Updates inkl.</span>
                        </div>
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Hosting & Domain oft enthalten</span>
                        </div>
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Feste monatliche Kosten</span>
                        </div>
                      </div>
                      <div className="pt-6 border-t border-white/10">
                        <div className="text-sm text-gray-400 mb-6 leading-relaxed">
                          Auswahl: {selectedIndustryData?.name}, Individuelles Design, Kunde liefert. Features: {selectedFeatures.map(id => features.find(f => f.id === id)?.name).join(', ')}
                        </div>
                        <Button className="w-full bg-gradient-to-r from-blue-600 to-blue-700 hover:from-blue-700 hover:to-blue-800 text-lg py-3 shadow-lg shadow-blue-500/30" asChild>
                          <Link to="/kontakt" onClick={() => handlePackageInterest('WebFlat')}>Mehr erfahren</Link>
                        </Button>
                      </div>
                    </CardContent>
                  </Card>

                  {/* SmartStart Package */}
                  <Card className="bg-gradient-to-br from-indigo-900/30 to-slate-800/30 backdrop-blur-sm border-indigo-400/30 relative overflow-hidden group hover:shadow-2xl hover:shadow-indigo-500/20 transition-all duration-500">
                    <div className="absolute inset-0 bg-gradient-to-br from-indigo-500/5 to-transparent opacity-0 group-hover:opacity-100 transition-opacity duration-500"></div>
                    <CardHeader className="text-center pb-6 relative z-10">
                      <div className="text-indigo-400 text-3xl font-bold mb-3">SmartStart</div>
                      <div className="text-gray-300 text-base mb-6">
                        Einmalige Investition & volle Kontrolle
                      </div>
                      <div className="flex items-baseline justify-center mb-3">
                        <span className="text-5xl font-bold text-white">{pricing.smartStartInitial}</span>
                        <span className="text-2xl font-bold text-white">,00 €</span>
                        <span className="text-gray-400 ml-3 text-lg">einmalig</span>
                      </div>
                      <div className="flex items-baseline justify-center">
                        <span className="text-3xl font-bold text-white">{pricing.smartStartMonthly}</span>
                        <span className="text-xl font-bold text-white">,00 €</span>
                        <span className="text-gray-400 ml-3">/ Monat</span>
                      </div>
                    </CardHeader>
                    <CardContent className="space-y-6 relative z-10">
                      <div className="space-y-4">
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Volles Eigentum an der Website</span>
                        </div>
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Höhere Flexibilität bei Änderungen</span>
                        </div>
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Keine langfristige Bindung</span>
                        </div>
                        <div className="flex items-center gap-3">
                          <Check className="h-6 w-6 text-green-400 flex-shrink-0" />
                          <span className="text-white text-base">Optionale Wartung buchbar</span>
                        </div>
                      </div>
                      <div className="pt-6 border-t border-white/10">
                        <div className="text-sm text-gray-400 mb-6 leading-relaxed">
                          Auswahl: {selectedIndustryData?.name}, Individuelles Design, Kunde liefert. Features: {selectedFeatures.map(id => features.find(f => f.id === id)?.name).join(', ')}
                        </div>
                        <Button className="w-full bg-gradient-to-r from-indigo-600 to-slate-600 hover:from-indigo-700 hover:to-slate-700 text-lg py-3 shadow-lg shadow-indigo-500/30" asChild>
                          <Link to="/kontakt" onClick={() => handlePackageInterest('SmartStart')}>Mehr erfahren</Link>
                        </Button>
                      </div>
                    </CardContent>
                  </Card>
                </div>

                <div className="text-center mt-12">
                  <p className="text-sm text-gray-500 max-w-3xl mx-auto leading-relaxed">
                    Die hier angezeigten Preise sind Schätzungen und nicht verbindlich. Der endgültige Preis wird nach individueller Absprache festgelegt.
                  </p>
                </div>
              </div>
            )}
          </div>
        </div>
      </div>
      <Footer />
    </>
  );
}
